==> jc-1.4.0.tar.gz: gnu/xml/transform/TransformerOutputProperties.h <==
// class gnu.xml.transform.TransformerOutputProperties

// class file dependencies
// @dep_class 91bdf930e0f67f86 gnu_xml_transform_TransformerOutputProperties
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 9092106fecd0cf9 java_util_Dictionary
// @dep_class 576421c2c18f78c4 java_util_Hashtable
// @dep_class 884c3edb343dfb63 java_util_Properties

// header file dependencies
// @dep_header java_util_Properties

#include "java/util/Properties.h"

#ifndef _JC_gnu_xml_transform_TransformerOutputProperties_H_
#define _JC_gnu_xml_transform_TransformerOutputProperties_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_refs	_jc_gnu_xml_transform_TransformerOutputProperties$sub_refs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs	_jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$refs	_jc_gnu_xml_transform_TransformerOutputProperties$refs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$nonrefs	_jc_gnu_xml_transform_TransformerOutputProperties$nonrefs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$object	_jc_gnu_xml_transform_TransformerOutputProperties$object;

typedef const struct _jc_gnu_xml_transform_TransformerOutputProperties$vmethods	_jc_gnu_xml_transform_TransformerOutputProperties$vmethods;
typedef const struct _jc_gnu_xml_transform_TransformerOutputProperties$vtable	_jc_gnu_xml_transform_TransformerOutputProperties$vtable;
typedef const struct _jc_gnu_xml_transform_TransformerOutputProperties$vtype	_jc_gnu_xml_transform_TransformerOutputProperties$vtype;

// Constructors
extern void _jc_gnu_xml_transform_TransformerOutputProperties$method$_init$12c4ddb4b942002a(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_gnu_xml_transform_Stylesheet$object *);

// Virtual methods
extern void _jc_gnu_xml_transform_TransformerOutputProperties$method$apply$419a858a98fff6e4(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *);
extern void _jc_gnu_xml_transform_TransformerOutputProperties$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *);
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_TransformerOutputProperties$method$getProperty$17fb18205ea95f87(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_String$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_TransformerOutputProperties$method$put$3bd1c078a0faa8da(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$apply$419a858a98fff6e4;
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$getProperty$17fb18205ea95f87;
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$put$3bd1c078a0faa8da;

// Virtual methods structure
struct _jc_gnu_xml_transform_TransformerOutputProperties$vmethods {
	void	(*apply$419a858a98fff6e4)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *);
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *);
	struct _jc_java_lang_String$object	*(*getProperty$17fb18205ea95f87)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_String$object *);
	struct _jc_java_lang_Object$object	*(*put$3bd1c078a0faa8da)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *);
};

// Vtable
struct _jc_gnu_xml_transform_TransformerOutputProperties$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Dictionary$vmethods	java_util_Dictionary;
	_jc_java_util_Hashtable$vmethods	java_util_Hashtable;
	_jc_java_util_Properties$vmethods	java_util_Properties;
	_jc_gnu_xml_transform_TransformerOutputProperties$vmethods	gnu_xml_transform_TransformerOutputProperties;
};

// Vtype
struct _jc_gnu_xml_transform_TransformerOutputProperties$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TransformerOutputProperties$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_refs {
	struct _jc_java_util_Properties$object	*defaultProperties;
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TransformerOutputProperties$refs {
    _jc_gnu_xml_transform_TransformerOutputProperties$sub_refs	gnu_xml_transform_TransformerOutputProperties;
    _jc_java_util_Properties$sub_refs	java_util_Properties;
    _jc_java_util_Hashtable$sub_refs	java_util_Hashtable;
    _jc_java_util_Dictionary$sub_refs	java_util_Dictionary;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs {
	jboolean	dirty;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TransformerOutputProperties$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Dictionary$sub_nonrefs	java_util_Dictionary;
    _jc_java_util_Hashtable$sub_nonrefs	java_util_Hashtable;
    _jc_java_util_Properties$sub_nonrefs	java_util_Properties;
    _jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs	gnu_xml_transform_TransformerOutputProperties;
};

// Object instance structure
struct _jc_gnu_xml_transform_TransformerOutputProperties$object {
	_jc_gnu_xml_transform_TransformerOutputProperties$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TransformerOutputProperties$vtype	*vtype;
	_jc_gnu_xml_transform_TransformerOutputProperties$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TransformerOutputProperties$vtype _jc_gnu_xml_transform_TransformerOutputProperties$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TransformerOutputProperties, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TransformerOutputProperties$class_object;

#endif	/* _JC_gnu_xml_transform_TransformerOutputProperties_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/transform/TransformerOutputProperties.h <==
// class gnu.xml.transform.TransformerOutputProperties

// class file dependencies
// @dep_class 91bdf930e0f67f86 gnu_xml_transform_TransformerOutputProperties
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 9092106fecd0cf9 java_util_Dictionary
// @dep_class 576421c2c18f78c4 java_util_Hashtable
// @dep_class 884c3edb343dfb63 java_util_Properties

// header file dependencies
// @dep_header java_util_Properties

#include "java/util/Properties.h"

#ifndef _JC_gnu_xml_transform_TransformerOutputProperties_H_
#define _JC_gnu_xml_transform_TransformerOutputProperties_H_

// Forward structure declarations
struct _jc_gnu_xml_transform_Stylesheet$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_java_util_Properties$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_refs	_jc_gnu_xml_transform_TransformerOutputProperties$sub_refs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs	_jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$refs	_jc_gnu_xml_transform_TransformerOutputProperties$refs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$nonrefs	_jc_gnu_xml_transform_TransformerOutputProperties$nonrefs;
typedef struct _jc_gnu_xml_transform_TransformerOutputProperties$object	_jc_gnu_xml_transform_TransformerOutputProperties$object;

typedef const struct _jc_gnu_xml_transform_TransformerOutputProperties$vmethods	_jc_gnu_xml_transform_TransformerOutputProperties$vmethods;
typedef const struct _jc_gnu_xml_transform_TransformerOutputProperties$vtable	_jc_gnu_xml_transform_TransformerOutputProperties$vtable;
typedef const struct _jc_gnu_xml_transform_TransformerOutputProperties$vtype	_jc_gnu_xml_transform_TransformerOutputProperties$vtype;

// Constructors
extern void _jc_gnu_xml_transform_TransformerOutputProperties$method$_init$12c4ddb4b942002a(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_gnu_xml_transform_Stylesheet$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_transform_TransformerOutputProperties$method$apply$419a858a98fff6e4(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_TransformerOutputProperties$method$clear$0a5acde3ee27a066(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_gnu_xml_transform_TransformerOutputProperties$method$getProperty$17fb18205ea95f87(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_TransformerOutputProperties$method$put$3bd1c078a0faa8da(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$apply$419a858a98fff6e4;
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$clear$0a5acde3ee27a066;
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$getProperty$17fb18205ea95f87;
extern _jc_method _jc_gnu_xml_transform_TransformerOutputProperties$method_info$put$3bd1c078a0faa8da;

// Virtual methods structure
struct _jc_gnu_xml_transform_TransformerOutputProperties$vmethods {
	void	(*apply$419a858a98fff6e4)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *) _JC_JCNI_ATTR;
	void	(*clear$0a5acde3ee27a066)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getProperty$17fb18205ea95f87)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*put$3bd1c078a0faa8da)(_jc_env *, struct _jc_gnu_xml_transform_TransformerOutputProperties$object *, struct _jc_java_lang_Object$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_TransformerOutputProperties$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_Dictionary$vmethods	java_util_Dictionary;
	_jc_java_util_Hashtable$vmethods	java_util_Hashtable;
	_jc_java_util_Properties$vmethods	java_util_Properties;
	_jc_gnu_xml_transform_TransformerOutputProperties$vmethods	gnu_xml_transform_TransformerOutputProperties;
};

// Vtype
struct _jc_gnu_xml_transform_TransformerOutputProperties$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_TransformerOutputProperties$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_refs {
	struct _jc_java_util_Properties$object	*defaultProperties;
	struct _jc_gnu_xml_transform_Stylesheet$object	*stylesheet;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_TransformerOutputProperties$refs {
    _jc_gnu_xml_transform_TransformerOutputProperties$sub_refs	gnu_xml_transform_TransformerOutputProperties;
    _jc_java_util_Properties$sub_refs	java_util_Properties;
    _jc_java_util_Hashtable$sub_refs	java_util_Hashtable;
    _jc_java_util_Dictionary$sub_refs	java_util_Dictionary;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs {
	jboolean	dirty;
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_TransformerOutputProperties$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_Dictionary$sub_nonrefs	java_util_Dictionary;
    _jc_java_util_Hashtable$sub_nonrefs	java_util_Hashtable;
    _jc_java_util_Properties$sub_nonrefs	java_util_Properties;
    _jc_gnu_xml_transform_TransformerOutputProperties$sub_nonrefs	gnu_xml_transform_TransformerOutputProperties;
};

// Object instance structure
struct _jc_gnu_xml_transform_TransformerOutputProperties$object {
	_jc_gnu_xml_transform_TransformerOutputProperties$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_TransformerOutputProperties$vtype	*vtype;
	_jc_gnu_xml_transform_TransformerOutputProperties$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_TransformerOutputProperties$vtype _jc_gnu_xml_transform_TransformerOutputProperties$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_TransformerOutputProperties, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_TransformerOutputProperties$class_object;

#endif	/* _JC_gnu_xml_transform_TransformerOutputProperties_H_ */
